import * as tslib_1 from "tslib";
import { Component, forwardRef, Input, ChangeDetectionStrategy } from '@angular/core';
import { IgxCategoryAxisBaseComponent } from "./igx-category-axis-base-component";
import { IgxAxisComponent } from "./igx-axis-component";
import { CategoryAngleAxis } from "./CategoryAngleAxis";
/**
 * Represents a IgxDataChartComponent category angle axis. Useful for displaying radial categories.
*
* `IgxCategoryAngleAxisComponent` represents a IgxDataChartComponent category angle axis. Useful for displaying radial categories
*
* ```html
* <igx-data-chart
*     [dataSource]="dataSource"   >
*     <igx-category-angle-axis name="angleAxis" label="Department" />
*     <igx-numeric-radius-axis name="radiusAxis" />
*  </igx-data-chart>
* ```
*/
export var IgxCategoryAngleAxisComponent_PROVIDERS = [{ provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(function () { return IgxCategoryAngleAxisComponent; }) }, { provide: IgxAxisComponent, useExisting: forwardRef(function () { return IgxCategoryAngleAxisComponent; }) }];
var IgxCategoryAngleAxisComponent = /** @class */ (function (_super) {
    tslib_1.__extends(IgxCategoryAngleAxisComponent, _super);
    function IgxCategoryAngleAxisComponent() {
        return _super.call(this) || this;
    }
    IgxCategoryAngleAxisComponent_1 = IgxCategoryAngleAxisComponent;
    IgxCategoryAngleAxisComponent.prototype.createImplementation = function () {
        return new CategoryAngleAxis();
    };
    Object.defineProperty(IgxCategoryAngleAxisComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryAngleAxisComponent.prototype, "isAngular", {
        /**
         * Checks if the axis is of angular type
        */
        get: function () {
            return this.i.b0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryAngleAxisComponent.prototype, "startAngleOffset", {
        /**
         * Indicates the angle in degress that the chart's 0th angle should be offset.
        *
        * Indicates the angle in degress that the chart's 0th angle should be offset.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="dataSource"   >
        *     <igx-category-angle-axis name="angleAxis" startAngleOffset=30/>
        *     <igx-numeric-radius-axis name="radiusAxis" />
        *  </igx-data-chart>
        * ```
        */
        get: function () {
            return this.i.li;
        },
        set: function (v) {
            this.i.li = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryAngleAxisComponent.prototype, "interval", {
        /**
         * Gets or sets the frequency of displayed labels.
         * The set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
        *
        * Gets or sets the frequency of displayed labels.The set value is a factor that determines which labels will be hidden.
        * For example, an interval of 2 will display every other label.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="dataSource"   >
        *     <igx-category-angle-axis name="angleAxis" interval =2 />
        *     <igx-numeric-radius-axis name="radiusAxis" />
        *  </igx-data-chart>
        * ```
        */
        get: function () {
            return this.i.lf;
        },
        set: function (v) {
            this.i.lf = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryAngleAxisComponent.prototype, "actualInterval", {
        /**
         * Gets the effective value for the current Interval.
        *
        * Gets the effective value for the current Interval.
        */
        get: function () {
            return this.i.k9;
        },
        set: function (v) {
            this.i.k9 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryAngleAxisComponent.prototype, "minorInterval", {
        /**
         * Gets or sets the frequency of displayed minor lines.
         * The set value is a factor that determines how the minor lines will be displayed.
        *
        * Gets or sets the frequency of displayed minor lines. The set value is a factor that determines how the minor lines will be displayed.
        */
        get: function () {
            return this.i.lg;
        },
        set: function (v) {
            this.i.lg = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCategoryAngleAxisComponent.prototype, "actualMinorInterval", {
        /**
         * Gets the effective value for the current MinorInterval.
        *
        * Get the effective value for the current minorInterval.
        */
        get: function () {
            return this.i.la;
        },
        set: function (v) {
            this.i.la = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Gets the scaled angle in radians from the raw axis value.
    
    * @param unscaledAngle  * The raw axis value.
    */
    IgxCategoryAngleAxisComponent.prototype.getScaledAngle = function (unscaledAngle) {
        var iv = this.i.getScaledAngle(unscaledAngle);
        return (iv);
    };
    /**
     * Gets the raw axis value from the scaled angle in radians.
    
    */
    IgxCategoryAngleAxisComponent.prototype.getUnscaledAngle = function (scaledAngle) {
        var iv = this.i.getUnscaledAngle(scaledAngle);
        return (iv);
    };
    var IgxCategoryAngleAxisComponent_1;
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxCategoryAngleAxisComponent.prototype, "startAngleOffset", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxCategoryAngleAxisComponent.prototype, "interval", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxCategoryAngleAxisComponent.prototype, "actualInterval", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxCategoryAngleAxisComponent.prototype, "minorInterval", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxCategoryAngleAxisComponent.prototype, "actualMinorInterval", null);
    IgxCategoryAngleAxisComponent = IgxCategoryAngleAxisComponent_1 = tslib_1.__decorate([
        Component({
            selector: 'igx-category-angle-axis',
            template: "",
            providers: [{ provide: IgxCategoryAxisBaseComponent, useExisting: forwardRef(function () { return IgxCategoryAngleAxisComponent_1; }) }, { provide: IgxAxisComponent, useExisting: forwardRef(function () { return IgxCategoryAngleAxisComponent_1; }) }],
            changeDetection: ChangeDetectionStrategy.OnPush
        }),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxCategoryAngleAxisComponent);
    return IgxCategoryAngleAxisComponent;
}(IgxCategoryAxisBaseComponent));
export { IgxCategoryAngleAxisComponent };
//# sourceMappingURL=igx-category-angle-axis-component.js.map