import * as tslib_1 from "tslib";
import { EventEmitter, Output, Input } from '@angular/core';
import { delegateCombine } from "igniteui-angular-core";
import { ChartHitTestMode, ChartHitTestMode_$type } from "./ChartHitTestMode";
import { WindowResponse, WindowResponse_$type } from "./WindowResponse";
import { Visibility, Visibility_$type } from "igniteui-angular-core";
import { InteractionState, InteractionState_$type } from "igniteui-angular-core";
import { ModifierKeys, ModifierKeys_$type } from "igniteui-angular-core";
import { HorizontalAlignment, HorizontalAlignment_$type } from "igniteui-angular-core";
import { IgxChartCursorEventArgs } from "./igx-chart-cursor-event-args";
import { IgxDataChartMouseButtonEventArgs } from "./igx-data-chart-mouse-button-event-args";
import { IgxChartMouseEventArgs } from "./igx-chart-mouse-event-args";
import { IgxRectChangedEventArgs } from "igniteui-angular-core";
import { TypeRegistrar } from "igniteui-angular-core";
import { NamePatcher, fromPoint, toPoint, ensureBool, fromRect, toRect, ensureEnum, brushToString, stringToBrush, toSpinal, initializePropertiesFromCss } from "igniteui-angular-core";
/**
 * Represents a control for viewing series objects.
*/
export var IgxSeriesViewerComponent_PROVIDERS = [];
var IgxSeriesViewerComponent = /** @class */ (function () {
    function IgxSeriesViewerComponent() {
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._seriesCursorMouseMove = null;
        this._seriesMouseLeftButtonDown = null;
        this._seriesMouseLeftButtonUp = null;
        this._seriesMouseMove = null;
        this._seriesMouseEnter = null;
        this._seriesMouseLeave = null;
        this._windowRectChanged = null;
        this._sizeChanged = null;
        this._actualWindowRectChanged = null;
        this._gridAreaRectChanged = null;
        this._zoneRunner = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgxSeriesViewerComponent.prototype.createImplementation = function () {
        return null;
    };
    IgxSeriesViewerComponent.prototype.ngOnInit = function () {
    };
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        } /**
                                     * @hidden
                                     */,
        enumerable: true,
        configurable: true
    });
    IgxSeriesViewerComponent._createFromInternal = function (internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        var name = internal.$type.name;
        var externalName = "Igx" + name + "Component";
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    };
    IgxSeriesViewerComponent.prototype.onImplementationCreated = function () {
    };
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "crosshairPoint", {
        /**
         * Gets or sets the cross hair point (in world coordinates)
         * Either or both of the crosshair point's X and Y may be set to double.NaN, in which
         * case the relevant crosshair line is hidden.
        *
        * The `crosshairPoint` property is used to gets/sets the cross hair point (in world coordinates).
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     crosshairVisibility="visible"
        *     crosshairPoint={x:.8,y:.2}>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.crosshairPoint = {x:.8,y:.2};
        * ```
        */
        get: function () {
            return fromPoint(this.i.mi);
        },
        set: function (v) {
            this.i.mi = toPoint(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "animateSeriesWhenAxisRangeChanges", {
        /**
         * Gets or sets whether the series animations should be allowed when a range change has been detected on an axis.
        *
        * `animateSeriesWhenAxisRangeChanges` is a Boolean property to override the default behavior in which series do not animate if an axis range changes.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     animateSeriesWhenAxisRangeChanges=true>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         transitionInMode="accordionFromBottom"
        *         isTransitionInEnabled=true
        *         transitionInSpeedType="indexScaled"
        *         transitionDuration=1000>
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.animateSeriesWhenAxisRangeChanges = true;
        * ```
        */
        get: function () {
            return this.i.cd;
        },
        set: function (v) {
            this.i.cd = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "viewportRect", {
        /**
         * Gets the viewport rectangle associated with the SeriesViewer, the physical dimensions of the plot area.
        *
        * ```ts
        * let viewPortRect: IgxRect = this.chart.viewportRect;
        * ```
        */
        get: function () {
            return fromRect(this.i.m3);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "effectiveViewport", {
        /**
         * Gets the EffectiveViewport rectangle, representing the effective viewport area after margins have been subtracted.
        *
        *  ``ts
        * let viewport: IgxRect = this.chart.effectiveViewport;
        *
        * ```
        *
        * ```
        */
        get: function () {
            return fromRect(this.i.mu);
        },
        set: function (v) {
            this.i.mu = toRect(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "contentViewport", {
        /**
         * Represents the subset area within the viewport into which content should be mapped.
         * This is the projection of the current EffectiveViewport into the viewport at current zoom level.
        *
        * ```ts
        * let contentViewport: IgxRect = this.chart.contentViewport;
        * ```
        */
        get: function () {
            return fromRect(this.i.mt);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "windowRect", {
        /**
         * A rectangle representing the portion of the SeriesViewer currently in view.
         * A rectangle at X=0, Y=0 with a Height and Width of 1 implies the entire plotting area is in view.  A Height and Width of .5 would imply that the view is halfway zoomed in.
        *
        * You can set the `windowRect` to zoom in on an area of interest in the chart.
        *
        * ```ts
        * this.chart.windowRect = {left:0, top:1, width: .5, height: .5};
        * ```
        */
        get: function () {
            return fromRect(this.i.m4);
        },
        set: function (v) {
            this.i.m4 = toRect(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "useTiledZooming", {
        /**
         * Gets or sets whether the series viewer should use cached tiles during zooms rather than the default live content.
        */
        get: function () {
            return this.i.dj;
        },
        set: function (v) {
            this.i.dj = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "preferHigherResolutionTiles", {
        /**
         * Gets or sets whether the series viewer should prefer selecting higher resolution tiles over lower resolution tiles when performing tile zooming. Setting this to true will lower performance but increase quality.
        */
        get: function () {
            return this.i.db;
        },
        set: function (v) {
            this.i.db = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "zoomTileCacheSize", {
        /**
         * Gets or sets the maximum number of zoom tiles that the series viewer should cache while in tiled zooming mode.
        */
        get: function () {
            return this.i.e6;
        },
        set: function (v) {
            this.i.e6 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "highlightingTransitionDuration", {
        /**
         * Gets or sets the duration the highlighting/de-highlighting effects.
        *
        * The `highlightingTransitionDuration` property is used to set the time for highlighting transition in milliseconds .
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        * 	HighlightingTransitionDuration=500 >
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value" >
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * chart.HighlightingTransitionDuration=500;
        * ```
        */
        get: function () {
            return this.i.e5;
        },
        set: function (v) {
            this.i.e5 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "isPagePanningAllowed", {
        /**
         * Gets or sets the whether the series viewer can allow the page to pan if a control pan is not possible in the requested direction.
        */
        get: function () {
            return this.i.cy;
        },
        set: function (v) {
            this.i.cy = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "contentHitTestMode", {
        /**
         * Determines the method of hit testing used when mousing over elements in the chart.
        *
        * ```ts
        * this.chart.contentHitTestMode = ChartHitTestMode.Computational;
        * ```
        */
        get: function () {
            return this.i.ap;
        },
        set: function (v) {
            this.i.ap = ensureEnum(ChartHitTestMode_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualContentHitTestMode", {
        /**
         * Resolved method of hit testing used when the pointer is over elements in the chart.
        *
        * ```ts
        * let actualContentHitTestMode: ChartHitTestMode  =this.chart.actualContentHitTestMode;
        * ```
        */
        get: function () {
            return this.i.ao;
        },
        set: function (v) {
            this.i.ao = ensureEnum(ChartHitTestMode_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "isSurfaceInteractionDisabled", {
        /**
         * Gets or sets whether all surface interactions with the plot area should be disabled.
        *
        * The `isSurfaceInteractionDisabled` property is used to enable/disable interactions with the plot surface.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     isSurfaceInteractionDisabled=true>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * chart.isSurfaceInteractionDisabled=true;
        * ```
        */
        get: function () {
            return this.i.cz;
        },
        set: function (v) {
            this.i.cz = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "isMap", {
        /**
         * Indicates if this SeriesViewer is a map.
        */
        get: function () {
            return this.i.cx;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "windowResponse", {
        /**
         * The response to user panning and zooming: whether to update the view immediately while the user action is happening, or to defer the update to after the user action is complete.  The user action will be an action such as a mouse drag which causes panning and/or zooming to occur.
        *
        * The `windowResponse` property is used to set the response to user panning and zooming: whether to update the view immediately while the user action is happening, or to defer the update to after the user action is complete.
        * The user action will be an action such as a mouse drag which causes panning and/or zooming to occur.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     isHorizontalZoomEnabled=true
        *     windowResponse="deferred">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.windowResponse="deferred";
        * ```
        */
        get: function () {
            return this.i.ba;
        },
        set: function (v) {
            this.i.ba = ensureEnum(WindowResponse_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "windowRectMinWidth", {
        /**
         * Sets or gets the minimum width that the window rect is allowed to reach before being clamped.
         * Decrease this value if you want to allow for further zooming into the viewer.
         * If this value is lowered too much it can cause graphical corruption due to floating point arithmetic inaccuracy.
        *
        * The `windowRectMinWidth` property is used to set or get the minimum width that the window rect is allowed to reach before being clamped.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     isHorizontalZoomEnabled=true
        *     windowRectMinWidth=.2>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.WindowRectMinWidth=".2";
        * ```
        */
        get: function () {
            return this.i.ex;
        },
        set: function (v) {
            this.i.ex = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "crosshairVisibility", {
        /**
         * Gets or sets the current SeriesViewer's crosshair visibility override.
        *
        * The `crosshairVisibility` property is used to gets or sets the current Chart's crosshair visibility override. Note: setting this property does not affect the mobile browser version of the chart.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     crosshairVisibility="visible">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.crosshairVisibility = Visibility.Visible;
        * ```
        */
        get: function () {
            return this.i.m7;
        },
        set: function (v) {
            this.i.m7 = ensureEnum(Visibility_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "plotAreaBackground", {
        /**
         * Gets or sets the brush used as the background for the current SeriesViewer object's plot area.
        *
        * `plotAreaBackground` property set the background brush to the current Chart object's plot area.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     plotAreaBackground="#F0F8FF">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.plotAreaBackground="#F0F8FF";
        * ```
        */
        get: function () {
            return brushToString(this.i.md);
        },
        set: function (v) {
            this.i.md = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "defaultInteraction", {
        /**
         * Gets or sets the DefaultInteraction property.
         * The default interaction state defines the SeriesViewer's response to mouse events.
        *
        * The default interaction state defines the chart's response to mouse events.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     isHorizontalZoomEnabled=true
        *     defaultInteraction="dragPan">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.defaultInteraction = InteractionState.DragPan;
        * ```
        */
        get: function () {
            return this.i.bc;
        },
        set: function (v) {
            this.i.bc = ensureEnum(InteractionState_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "rightButtonDefaultInteraction", {
        /**
         * Gets or sets the RightButtonDefaultInteraction property.
         * The default interaction state defines the SeriesViewer's response to right button mouse events.
        */
        get: function () {
            return this.i.be;
        },
        set: function (v) {
            this.i.be = ensureEnum(InteractionState_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "dragModifier", {
        /**
         * Gets or sets the current SeriesViewer's DragModifier property.
        *
        * `dragModifier` is useful to enable zooming when zooming is not the default interaction.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     isHorizontalZoomEnabled=true
        *     defaultInteraction="dragPan"
        *     dragModifier="alt">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.dragModifier = ModifierKeys.Alt;
        * ```
        */
        get: function () {
            return this.i.l0;
        },
        set: function (v) {
            this.i.l0 = ensureEnum(ModifierKeys_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "panModifier", {
        /**
         * Gets or sets the current SeriesViewer's PanModifier property.
        *
        * `panModifier` is useful to enable panning when panning is not the default interaction.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     isHorizontalZoomEnabled=true
        *     defaultInteraction="dragZoom"
        *     panModifier="alt">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.panModifier = ModifierKeys.Alt;
        * ```
        */
        get: function () {
            return this.i.l1;
        },
        set: function (v) {
            this.i.l1 = ensureEnum(ModifierKeys_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "previewRect", {
        /**
         * Gets or sets the preview rectangle.
         * The preview rectangle may be set to Rect.Empty, in which case the visible preview
         * strokePath is hidden.
        *
        * `previewRect` can be used to highlight an area of importance.
        *
        * ```ts
        * this.chart.previewRect = {left:0,top:0,height:.5,width:.5};
        * ```
        */
        get: function () {
            return fromRect(this.i.mz);
        },
        set: function (v) {
            this.i.mz = toRect(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "windowPositionHorizontal", {
        /**
         * A number between 0 and 1 determining the position of the horizontal scroll.
         * This property is effectively a shortcut to the X position of the WindowRect property.
        *
        * ```ts
        * this.chart.windowPositionHorizontal = .2;
        * ```
        */
        get: function () {
            return this.i.ev;
        },
        set: function (v) {
            this.i.ev = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "windowPositionVertical", {
        /**
         * A number between 0 and 1 determining the position of the vertical scroll.
         * This property is effectively a shortcut to the Y position of the WindowRect property.
        *
        * ```ts
        * this.chart.windowPositionVertical = .2;
        * ```
        */
        get: function () {
            return this.i.ew;
        },
        set: function (v) {
            this.i.ew = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "chartTitle", {
        /**
         * Text to display above the plot area.
        *
        * The `chartTitle` property is used to set the title to display for the component.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.title="Items Sold";
        * ```
        */
        get: function () {
            return this.i.gq;
        },
        set: function (v) {
            this.i.gq = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleHorizontalAlignment", {
        /**
         * Gets or sets the TitleHorizontalAlignment property.
        *
        * The `subtitleHorizontalAlignment` property is used to set horizontal alignment for the subtitle.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="date of sale: 1/1/2018"
        *     titleHorizontalAlignment="left"
        *     subtitleHorizontalAlignment="left">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.titleHorizontalAlignment="left";
        * ```
        */
        get: function () {
            return this.i.lz;
        },
        set: function (v) {
            this.i.lz = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleHorizontalAlignment", {
        /**
         * Gets or sets the SubtitleHorizontalAlignment property.
        *
        * The `subtitleBottomMargin` property is used to set the horizontal alignment for the subtitle.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="Date of Sale: 1/1/2018"
        *     titleHorizontalAlignment="left"
        *     subtitleHorizontalAlignment="left">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleHorizontalAlignment="left";
        * ```
        */
        get: function () {
            return this.i.ly;
        },
        set: function (v) {
            this.i.ly = ensureEnum(HorizontalAlignment_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleTextStyle", {
        /**
         * Font settings for the title.
        */
        get: function () {
            return this.i.gx;
        },
        set: function (v) {
            this.i.gx = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleTextStyle", {
        /**
         * Font settings for the subtitle.
        */
        get: function () {
            return this.i.gl;
        },
        set: function (v) {
            this.i.gl = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleTextColor", {
        /**
         * Gets or sets the Color used for the Title Text.
        *
        * The `titleTextColor` property is used to set the title brush.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="date of sale: 1/1/2018"
        *     titleTextColor="blue">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.titleTextColor="blue" ;
        * ```
        */
        get: function () {
            return brushToString(this.i.mg);
        },
        set: function (v) {
            this.i.mg = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleTextColor", {
        /**
         * Gets or sets the Color used for the Subtitle Text.
        *
        * The `subtitleTextColor` property is used to set the color for the subtitle.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="Date of Sale: 1/1/2018"
        *     subtitleTextColor="blue">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleTextColor="blue";
        * ```
        */
        get: function () {
            return brushToString(this.i.mf);
        },
        set: function (v) {
            this.i.mf = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleTopMargin", {
        /**
         * Margin applied above the title.
        *
        * The `titleTopMargin` property is used to set the top margin for the title.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     titleLeftMarging=10
        *     titleTopMargin=10
        *     titleRightMargin=10
        *     titleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.titleTopMargin=10;
        * ```
        */
        get: function () {
            return this.i.et;
        },
        set: function (v) {
            this.i.et = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleLeftMargin", {
        /**
         * Margin applied to the left of the title.
        *
        * The `titleLeftMarging` property is used to set the left margin for the title.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     titleLeftMarging=10
        *     titleTopMargin=10
        *     titleRightMargin=10
        *     titleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.titleLeftMarging=10;
        * ```
        */
        get: function () {
            return this.i.er;
        },
        set: function (v) {
            this.i.er = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleRightMargin", {
        /**
         * Margin applied to the right of the title.
        *
        * The `titleRightMargin` property is used to set the right margin for the title.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     titleLeftMarging=10
        *     titleTopMargin=10
        *     titleRightMargin=10
        *     titleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.titleRightMargin=10;
        * ```
        */
        get: function () {
            return this.i.es;
        },
        set: function (v) {
            this.i.es = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "titleBottomMargin", {
        /**
         * Margin applied below the title.
        *
        * The `titleBottomMargin` property is used to set the bottom margin for the title.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     titleLeftMarging=10
        *     titleTopMargin=10
        *     titleRightMargin=10
        *     titleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.titleBottomMargin=20;
        * ```
        */
        get: function () {
            return this.i.eq;
        },
        set: function (v) {
            this.i.eq = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleTopMargin", {
        /**
         * Margin applied above the subtitle.
        *
        * The `subtitleTopMargin` property is used to set the top margin for the subtitle.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="date of sale: 1/1/2018"
        *     subtitleLeftMarging=10
        *     subtitleTopMargin=10
        *     subtitleRightMargin=10
        *     subtitleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleTopMargin =10;
        * ```
        */
        get: function () {
            return this.i.ep;
        },
        set: function (v) {
            this.i.ep = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleLeftMargin", {
        /**
         * Margin applied to the left of the subtitle.
        *
        * The `subtitleLeftMarging` property is used to set the left margin for the subtitle.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="date of sale: 1/1/2018"
        *     subtitleLeftMarging=10
        *     subtitleTopMargin=10
        *     subtitleRightMargin=10
        *     subtitleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleLeftMarging=10;
        * ```
        */
        get: function () {
            return this.i.en;
        },
        set: function (v) {
            this.i.en = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleRightMargin", {
        /**
         * Margin applied to the right of the subtitle.
        *
        * The `subTitleRightMargin` property is used to set the right margin for the subtitle.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="date of sale: 1/1/2018"
        *     subtitleLeftMarging=10
        *     subtitleTopMargin=10
        *     subTitleRightMargin=10
        *     subtitleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleLeftMarging=10;
        * ```
        */
        get: function () {
            return this.i.eo;
        },
        set: function (v) {
            this.i.eo = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitleBottomMargin", {
        /**
         * Margin applied below the subtitle.
        *
        * The `subtitleBottomMargin` property is used to set the bottom margin for the subtitle.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="date of sale: 1/1/2018"
        *     subtitleLeftMarging=10
        *     subtitleTopMargin=10
        *     subtitleRightMargin=10
        *     subtitleBottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitleBottomMargin = 20;
        * ```
        */
        get: function () {
            return this.i.em;
        },
        set: function (v) {
            this.i.em = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "subtitle", {
        /**
         * Gets or sets the Subtitle property.
         * The Title property defines the Subtitle of the chart
        *
        * The `subtitle` property is used to display subtitle for the component.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     title="Items Sold"
        *     subtitle="Date of Sale: 1/1/2018">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.subtitle="Date of Sale: 1/1/2018";
        * ```
        */
        get: function () {
            return this.i.ge;
        },
        set: function (v) {
            this.i.ge = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "topMargin", {
        /**
         * Sets or gets the top margin to use around the chart content.
        *
        * The `topMargin` property is used to set the top margin.
        *
        * ```html
        *  <igx-data-chart
        *     [dataSource]="data"
        *     leftMargin=20
        *     rightMargin=20
        *     topMargin=30
        *     bottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.topMargin=30;
        * ```
        */
        get: function () {
            return this.i.eu;
        },
        set: function (v) {
            this.i.eu = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "leftMargin", {
        /**
         * Sets or gets the left margin to use around the chart content.
        *
        * The `leftMargin` property is used to set the left margin.
        *
        * ```html
        *  <igx-data-chart
        *     [dataSource]="data"
        *     leftMargin=20
        *     rightMargin=20
        *     topMargin=30
        *     bottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        *  this.chart.leftMargin = 20;
        * ```
        */
        get: function () {
            return this.i.ej;
        },
        set: function (v) {
            this.i.ej = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "rightMargin", {
        /**
         * Sets or gets the right margin to use around the chart content.
        *
        * The `rightMargin` property is used to set the left margin around the chart content in the canvas.
        *
        * ```html
        *  <igx-data-chart
        *     [dataSource]="data"
        *     leftMargin=20
        *     rightMargin=20
        *     topMargin=30
        *     bottomMargin=20>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.rightMargin=20;
        * ```
        */
        get: function () {
            return this.i.el;
        },
        set: function (v) {
            this.i.el = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "bottomMargin", {
        /**
         * Sets or gets the bottom margin to use around the chart content.
        *
        * The `bottomMargin` property is used to gets/set the bottom margin around the chart content in the canvas.
        *
        * ```ts
        * this.chart.bottomMargin = 50;
        * ```
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     bottomMargin=50>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        */
        get: function () {
            return this.i.ef;
        },
        set: function (v) {
            this.i.ef = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "autoMarginWidth", {
        /**
         * Sets or gets the automatic width to add when automatically adding margins to the chart.
        *
        * The `autoMarginWidth` propertry is used find the automatic width to add when automatically adding margins to the chart.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     autoMarginWidth=50>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * this.chart.autoMarginWidth = 50;
        * ```
        */
        get: function () {
            return this.i.ee;
        },
        set: function (v) {
            this.i.ee = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "autoMarginHeight", {
        /**
         * Sets or gets the automatic height to add when automatically adding margins to the chart.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     autoMarginHeight=50>
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-column-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-column-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        *  this.chart.autoMarginHeight = 50;
        * ```
        */
        get: function () {
            return this.i.ed;
        },
        set: function (v) {
            this.i.ed = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "isAntiAliasingEnabledDuringInteraction", {
        /**
         * Gets or sets the IsAntiAliasingEnabledDuringInteraction property.
        */
        get: function () {
            return this.i.cp;
        },
        set: function (v) {
            this.i.cp = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "pixelScalingRatio", {
        /**
         * Gets or sets the scaling value used to affect the pixel density of the control.
         * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
         * to appear blurry.
        */
        get: function () {
            return this.i.ek;
        },
        set: function (v) {
            this.i.ek = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "interactionPixelScalingRatio", {
        /**
         * Method of pixel scaling to use during end user interaction with the chart.
        */
        get: function () {
            return this.i.ei;
        },
        set: function (v) {
            this.i.ei = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualPixelScalingRatio", {
        /**
         * Gets the resolved pixel scaling ratio.
        *
        * A higher scaling ratio will produce crisper visuals at the expense of memory. Lower values will cause the control to appear blurry
        *
        * ```ts
        * let actualPixelScalingRatio: number = this.chart.actualPixelScalingRatio;
        * ```
        */
        get: function () {
            return this.i.ea;
        },
        set: function (v) {
            this.i.ea = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualInteractionPixelScalingRatio", {
        /**
         * Resolved method of pixel scaling to use during end user interaction with the chart.
        *
        * ```ts
        * let actualInteractionPixelScalingRatio: number = this.chart.actualInteractionPixelScalingRatio;
        * ```
        */
        get: function () {
            return this.i.d9;
        },
        set: function (v) {
            this.i.d9 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualWindowRect", {
        /**
         * Gets the actual value of the window rectangle, which represents the current zoom level.
        *
        * ```ts
        * let actualWindowRect: IgxRect = this.chart.actualWindowRect;
        * ``
        * ```
        */
        get: function () {
            return fromRect(this.i.mq);
        },
        set: function (v) {
            this.i.mq = toRect(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualWindowPositionHorizontal", {
        /**
         * A number between 0 and 1 determining the position of the horizontal scroll.
         * This property is effectively a shortcut to the Left of the ActualWindowRect property.
        *
        * ```ts
        * let actualWindowPositionHorizontal: number = this.chart.actualWindowPositionHorizontal;
        * ```
        */
        get: function () {
            return this.i.eb;
        },
        set: function (v) {
            this.i.eb = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualWindowPositionVertical", {
        /**
         * A number between 0 and 1 determining the position of the vertical scroll.
         * This property is effectively a shortcut to the Top of the ActualWindowRect property.
        *
        * ```ts
        * let actualWindowPositionVertical: number = this.chart.actualWindowPositionVertical;
        * ``
        * ```
        */
        get: function () {
            return this.i.ec;
        },
        set: function (v) {
            this.i.ec = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "hasUserValues", {
        get: function () {
            return this._hasUserValues;
        },
        enumerable: true,
        configurable: true
    });
    IgxSeriesViewerComponent.prototype.__m = function (propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    };
    IgxSeriesViewerComponent.prototype._styling = function (container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        var genericPrefix = "";
        var typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("SeriesViewerComponent");
        var additionalPrefixes = [];
        var prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        var b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            var basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            var parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            var parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    };
    /**
     * Hides the active main tooltip, if displayed.
    
    *
    * ```ts
    * this.chart.hideToolTip();
    * ```
    */
    IgxSeriesViewerComponent.prototype.hideToolTip = function () {
        this.i.ho();
    };
    /**
     * Manually starts a tiled zoom if one isn't already running.
    
    */
    IgxSeriesViewerComponent.prototype.startTiledZoomingIfNecessary = function () {
        this.i.j7();
    };
    /**
     * Manually ends a tiled zoom if one is running.
    
    */
    IgxSeriesViewerComponent.prototype.endTiledZoomingIfRunning = function () {
        this.i.hj();
    };
    /**
     * Clears the tile zoom tile cache so that new tiles will be generated. Only applies if the viewer is using a tile based zoom.
    
    */
    IgxSeriesViewerComponent.prototype.clearTileZoomCache = function () {
        this.i.hd();
    };
    /**
     * Resets the zoom level to default.
    
    */
    IgxSeriesViewerComponent.prototype.resetZoom = function () {
        this.i.j1();
    };
    /**
     * Gets actual window scale for horizontal dimension of the control
    
    *
    * ```ts
    * let actualWindowScaleHorizontal: number = chart.getActualWindowScaleHorizontal();
    * ```
    */
    IgxSeriesViewerComponent.prototype.getActualWindowScaleHorizontal = function () {
        var iv = this.i.eg();
        return (iv);
    };
    /**
     * Gets actual window scale for vertical dimension of the control
    
    *
    * ```ts
    * let actualWindowScaleVertical: number = chart.getActualWindowScaleVertical();
    * ```
    */
    IgxSeriesViewerComponent.prototype.getActualWindowScaleVertical = function () {
        var iv = this.i.eh();
        return (iv);
    };
    /**
     * Notification from the containing object that the container has been resized.
    
    */
    IgxSeriesViewerComponent.prototype.notifyContainerResized = function () {
        this.i.notifyContainerResized();
    };
    /**
     * Attaches the given series to the chart.
    
    * @param s  * The series to attach to the chart.
    */
    IgxSeriesViewerComponent.prototype.attachSeries = function (s) {
        this.i.hb((s == null ? null : s.i));
    };
    IgxSeriesViewerComponent.prototype.notifySetItem = function (source_, index, oldItem, newItem) {
        this.i.h0(source_, index, oldItem, newItem);
    };
    /**
     * Used to manually notify the SeriesViewer that the data source has reset or cleared its items.  Invoking this method is only necessary if that datasource is not observable.
    
    * @param source_  * The data source which was cleared or reset.
    *
    * ```ts
    * this.chart.notifyClearItems(this.data);
    * ```
    */
    IgxSeriesViewerComponent.prototype.notifyClearItems = function (source_) {
        this.i.hv(source_);
    };
    IgxSeriesViewerComponent.prototype.notifyInsertItem = function (source_, index, newItem) {
        this.i.hy(source_, index, newItem);
    };
    IgxSeriesViewerComponent.prototype.notifyRemoveItem = function (source_, index, oldItem) {
        this.i.hz(source_, index, oldItem);
    };
    /**
     * Release any resources held by the control.
    
    */
    IgxSeriesViewerComponent.prototype.destroy = function () {
        this.i.destroy();
    };
    /**
     * Use to force the SeriesViewer to finish any deferred work before printing or evaluating its visual.
     * This should only be called if the visual of the SeriesViewer needs to be synchronously saved or evaluated.
     * Calling this method too often will hinder the performance of the SeriesViewer.
    
    *
    * ```ts
    * this.chart.flush();
    * ```
    */
    IgxSeriesViewerComponent.prototype.flush = function () {
        this.i.flush();
    };
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "seriesCursorMouseMove", {
        /**
         * Occurs when the cursors are moved over a series in this SeriesViewer.
        */
        get: function () {
            var _this = this;
            if (this._seriesCursorMouseMove == null) {
                this._seriesCursorMouseMove = new EventEmitter();
                this.i.seriesCursorMouseMove = delegateCombine(this.i.seriesCursorMouseMove, function (o, e) {
                    var outerArgs = new IgxChartCursorEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeSeriesCursorMouseMove) {
                        _this.beforeSeriesCursorMouseMove(_this, outerArgs);
                    }
                    _this._seriesCursorMouseMove.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._seriesCursorMouseMove;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "seriesMouseLeftButtonDown", {
        /**
         * Occurs when the left mouse button is pressed while the mouse pointer is over a Series.
        *
        * The `SeriesMouseLeftButtonDown` event occurs when the left mouse button is pressed while the mouse pointer is over an element of this chart.
        *
        * &lt;-- position: content member-->
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     (seriesMouseLeftButtonDown)="onSeriesMouseLeftButtonDown($event)">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         thickness=5>
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * public onSeriesMouseLeftButtonDown(event: {sender: any, args: DataChartMouseButtonEventArgs})
        * {
        *     var item = event.args.item;
        * }
        * ```
        */
        get: function () {
            var _this = this;
            if (this._seriesMouseLeftButtonDown == null) {
                this._seriesMouseLeftButtonDown = new EventEmitter();
                this.i.seriesMouseLeftButtonDown = delegateCombine(this.i.seriesMouseLeftButtonDown, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxDataChartMouseButtonEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesMouseLeftButtonDown) {
                            _this.beforeSeriesMouseLeftButtonDown(_this, outerArgs);
                        }
                        _this._seriesMouseLeftButtonDown.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesMouseLeftButtonDown;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "seriesMouseLeftButtonUp", {
        /**
         * Occurs when the left mouse button is released while the mouse pointer is over a Series.
        *
        * The `SeriesMouseLeftButtonUp` event occurs when the left mouse button is released while the mouse pointer is over an element of this chart.
        *
        * &lt;-- position: content member-->
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     (seriesMouseLeftButtonUp)="onSeriesMouseLeftButtonUp($event)">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         thickness=5>
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * &lt;-- position: content member-->
        *
        * ```ts
        * public onSeriesMouseLeftButtonUp(event: {sender: any, args: DataChartMouseButtonEventArgs})
        * {
        *     var item = event.args.item;
        * }
        * ```
        *
        * ```ts
        * public onSeriesMouseLeftButtonUp =(event: any, args: DataChartMouseButtonEventArgs )
        * {
        *
        * }
        * ```
        */
        get: function () {
            var _this = this;
            if (this._seriesMouseLeftButtonUp == null) {
                this._seriesMouseLeftButtonUp = new EventEmitter();
                this.i.seriesMouseLeftButtonUp = delegateCombine(this.i.seriesMouseLeftButtonUp, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxDataChartMouseButtonEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesMouseLeftButtonUp) {
                            _this.beforeSeriesMouseLeftButtonUp(_this, outerArgs);
                        }
                        _this._seriesMouseLeftButtonUp.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesMouseLeftButtonUp;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "seriesMouseMove", {
        /**
         * Occurs when the mouse pointer moves while over a Series.
        *
        * The `SeriesMouseMove` event occurs when the left mouse pointer moves while over an element of this chart.
        *
        * &lt;-- position: content member-->
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     (seriesMouseMove)="onSeriesMouseMove($event)">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         thickness=5>
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * &lt;-- position: content member-->
        *
        * ```ts
        * public onSeriesMouseMove(event: {sender: any, args: ChartMouseEventArgs})
        * {
        *     var item = event.args.item;
        * }
        * ```
        *
        * ```ts
        * public onSeriesMouseMove =( event: any, args: ChartMouseEventArgs) => {
        *                  }
        * ```
        */
        get: function () {
            var _this = this;
            if (this._seriesMouseMove == null) {
                this._seriesMouseMove = new EventEmitter();
                this.i.seriesMouseMove = delegateCombine(this.i.seriesMouseMove, function (o, e) {
                    var outerArgs = new IgxChartMouseEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeSeriesMouseMove) {
                        _this.beforeSeriesMouseMove(_this, outerArgs);
                    }
                    _this._seriesMouseMove.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._seriesMouseMove;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "seriesMouseEnter", {
        /**
         * Occurs when the mouse pointer enters a Series.
        *
        * The `SeriesMouseEnter` event occurs when the left mouse pointer enters an element of this chart.
        *
        * &lt;-- position: content member-->
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     (seriesMouseEnter)="onSeriesMouseEnter($event)">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         thickness=5>
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * public onSeriesMouseEnter(event: {sender: any, args: ChartMouseEventArgs})
        * {
        *     var item = event.args.item;
        * }
        * ```
        */
        get: function () {
            var _this = this;
            if (this._seriesMouseEnter == null) {
                this._seriesMouseEnter = new EventEmitter();
                this.i.seriesMouseEnter = delegateCombine(this.i.seriesMouseEnter, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxChartMouseEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesMouseEnter) {
                            _this.beforeSeriesMouseEnter(_this, outerArgs);
                        }
                        _this._seriesMouseEnter.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesMouseEnter;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "seriesMouseLeave", {
        /**
         * Occurs when the mouse pointer leaves a Series.
        *
        * The `SeriesMouseLeave` event occurs when the left mouse pointer leaves an element of this chart.
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     (seriesMouseLeave)="onSeriesMouseLeave($event)">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value"
        *         thickness=5>
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * ```ts
        * public onSeriesMouseLeave(event: {sender: any, args: ChartMouseEventArgs})
        * {
        *     var item = event.args.item;
        * }
        * ```
        */
        get: function () {
            var _this = this;
            if (this._seriesMouseLeave == null) {
                this._seriesMouseLeave = new EventEmitter();
                this.i.seriesMouseLeave = delegateCombine(this.i.seriesMouseLeave, function (o, e) {
                    _this._runInZone(function () {
                        var outerArgs = new IgxChartMouseEventArgs();
                        outerArgs._provideImplementation(e);
                        if (_this.beforeSeriesMouseLeave) {
                            _this.beforeSeriesMouseLeave(_this, outerArgs);
                        }
                        _this._seriesMouseLeave.emit({
                            sender: _this,
                            args: outerArgs
                        });
                    });
                });
            }
            return this._seriesMouseLeave;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "windowRectChanged", {
        /**
         * Occurs just after the current SeriesViewer's window rectangle is changed.
        *
        * &lt;-- position: content member-->
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     isHorizontalZoomEnabled=true
        *     (windowRectChanged)="onWindowRectChanged($event)">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * &lt;-- position: content member-->
        *
        * ```ts
        * public onWindowRectChanged(event: {sender: any, args: RectChangedEventArgs})
        * {
        *     let newRect: IgxRect = event.args.newRect;
        * }
        * ```
        *
        * ```ts
        * public onWindowRectChanged =( s:any, e: RectChangedEventArgs) => {
        *
        *        }
        * ```
        */
        get: function () {
            var _this = this;
            if (this._windowRectChanged == null) {
                this._windowRectChanged = new EventEmitter();
                this.i.windowRectChanged = delegateCombine(this.i.windowRectChanged, function (o, e) {
                    var outerArgs = new IgxRectChangedEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeWindowRectChanged) {
                        _this.beforeWindowRectChanged(_this, outerArgs);
                    }
                    _this._windowRectChanged.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._windowRectChanged;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "sizeChanged", {
        /**
         * Occurs after the size of the series viewer changes.
        *
        * &lt;-- position: content member-->
        *
        * ```html
        * <igx-data-chart
        *     [dataSource]="data"
        *     (sizeChanged)="onSizeChanged($event)">
        *     <igx-category-x-axis
        *         label="label"
        *         #xAxis>
        *     </igx-category-x-axis>
        *     <igx-numeric-y-axis
        *         #yAxis>
        *     </igx-numeric-y-axis>
        *     <igx-line-series
        *         [xAxis]="xAxis"
        *         [yAxis]="yAxis"
        *         valueMemberPath="value">
        *     </igx-line-series>
        * </igx-data-chart>
        * ```
        *
        * &lt;-- position: content member-->
        *
        * ```ts
        * public onSizeChanged(event: {sender: any, args: RectChangedEventArgs})
        * {
        *     let newRect: IgxRect = event.args.newRect;
        * }
        * ```
        *
        * ```ts
        * public onSizeChanged =(event: any, args: RectChangedEventArgs}){
        *
        * }
        * ```
        */
        get: function () {
            var _this = this;
            if (this._sizeChanged == null) {
                this._sizeChanged = new EventEmitter();
                this.i.sizeChanged = delegateCombine(this.i.sizeChanged, function (o, e) {
                    var outerArgs = new IgxRectChangedEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeSizeChanged) {
                        _this.beforeSizeChanged(_this, outerArgs);
                    }
                    _this._sizeChanged.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._sizeChanged;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "actualWindowRectChanged", {
        /**
         * Raised when the actual window rectangle of the SeriesViewer changes.
        */
        get: function () {
            var _this = this;
            if (this._actualWindowRectChanged == null) {
                this._actualWindowRectChanged = new EventEmitter();
                this.i.actualWindowRectChanged = delegateCombine(this.i.actualWindowRectChanged, function (o, e) {
                    var outerArgs = new IgxRectChangedEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeActualWindowRectChanged) {
                        _this.beforeActualWindowRectChanged(_this, outerArgs);
                    }
                    _this._actualWindowRectChanged.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._actualWindowRectChanged;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxSeriesViewerComponent.prototype, "gridAreaRectChanged", {
        /**
         * Occurs just after the current SeriesViewer's grid area rectangle is changed.
         * The grid area may change as the result of the SeriesViewer being resized, or
         * of an axis being added or changing size, possibly in another SeriesViewer.
        */
        get: function () {
            var _this = this;
            if (this._gridAreaRectChanged == null) {
                this._gridAreaRectChanged = new EventEmitter();
                this.i.gridAreaRectChanged = delegateCombine(this.i.gridAreaRectChanged, function (o, e) {
                    var outerArgs = new IgxRectChangedEventArgs();
                    outerArgs._provideImplementation(e);
                    if (_this.beforeGridAreaRectChanged) {
                        _this.beforeGridAreaRectChanged(_this, outerArgs);
                    }
                    _this._gridAreaRectChanged.emit({
                        sender: _this,
                        args: outerArgs
                    });
                });
            }
            return this._gridAreaRectChanged;
        },
        enumerable: true,
        configurable: true
    });
    IgxSeriesViewerComponent.prototype._runInZone = function (act) {
        if (this._zoneRunner != null) {
            this._zoneRunner(act);
        }
        else {
            act();
        }
    };
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object),
        tslib_1.__metadata("design:paramtypes", [Object])
    ], IgxSeriesViewerComponent.prototype, "crosshairPoint", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean),
        tslib_1.__metadata("design:paramtypes", [Boolean])
    ], IgxSeriesViewerComponent.prototype, "animateSeriesWhenAxisRangeChanges", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object),
        tslib_1.__metadata("design:paramtypes", [Object])
    ], IgxSeriesViewerComponent.prototype, "effectiveViewport", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object),
        tslib_1.__metadata("design:paramtypes", [Object])
    ], IgxSeriesViewerComponent.prototype, "windowRect", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean),
        tslib_1.__metadata("design:paramtypes", [Boolean])
    ], IgxSeriesViewerComponent.prototype, "useTiledZooming", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean),
        tslib_1.__metadata("design:paramtypes", [Boolean])
    ], IgxSeriesViewerComponent.prototype, "preferHigherResolutionTiles", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "zoomTileCacheSize", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "highlightingTransitionDuration", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean),
        tslib_1.__metadata("design:paramtypes", [Boolean])
    ], IgxSeriesViewerComponent.prototype, "isPagePanningAllowed", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "contentHitTestMode", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "actualContentHitTestMode", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean),
        tslib_1.__metadata("design:paramtypes", [Boolean])
    ], IgxSeriesViewerComponent.prototype, "isSurfaceInteractionDisabled", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "windowResponse", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "windowRectMinWidth", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "crosshairVisibility", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String),
        tslib_1.__metadata("design:paramtypes", [String])
    ], IgxSeriesViewerComponent.prototype, "plotAreaBackground", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "defaultInteraction", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "rightButtonDefaultInteraction", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "dragModifier", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "panModifier", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object),
        tslib_1.__metadata("design:paramtypes", [Object])
    ], IgxSeriesViewerComponent.prototype, "previewRect", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "windowPositionHorizontal", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "windowPositionVertical", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String),
        tslib_1.__metadata("design:paramtypes", [String])
    ], IgxSeriesViewerComponent.prototype, "chartTitle", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "titleHorizontalAlignment", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "subtitleHorizontalAlignment", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String),
        tslib_1.__metadata("design:paramtypes", [String])
    ], IgxSeriesViewerComponent.prototype, "titleTextStyle", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String),
        tslib_1.__metadata("design:paramtypes", [String])
    ], IgxSeriesViewerComponent.prototype, "subtitleTextStyle", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String),
        tslib_1.__metadata("design:paramtypes", [String])
    ], IgxSeriesViewerComponent.prototype, "titleTextColor", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String),
        tslib_1.__metadata("design:paramtypes", [String])
    ], IgxSeriesViewerComponent.prototype, "subtitleTextColor", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "titleTopMargin", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "titleLeftMargin", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "titleRightMargin", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "titleBottomMargin", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "subtitleTopMargin", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "subtitleLeftMargin", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "subtitleRightMargin", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "subtitleBottomMargin", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", String),
        tslib_1.__metadata("design:paramtypes", [String])
    ], IgxSeriesViewerComponent.prototype, "subtitle", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "topMargin", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "leftMargin", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "rightMargin", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "bottomMargin", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "autoMarginWidth", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "autoMarginHeight", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Boolean),
        tslib_1.__metadata("design:paramtypes", [Boolean])
    ], IgxSeriesViewerComponent.prototype, "isAntiAliasingEnabledDuringInteraction", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "pixelScalingRatio", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "interactionPixelScalingRatio", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "actualPixelScalingRatio", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "actualInteractionPixelScalingRatio", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Object),
        tslib_1.__metadata("design:paramtypes", [Object])
    ], IgxSeriesViewerComponent.prototype, "actualWindowRect", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "actualWindowPositionHorizontal", null);
    tslib_1.__decorate([
        Input(),
        tslib_1.__metadata("design:type", Number),
        tslib_1.__metadata("design:paramtypes", [Number])
    ], IgxSeriesViewerComponent.prototype, "actualWindowPositionVertical", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxSeriesViewerComponent.prototype, "seriesCursorMouseMove", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxSeriesViewerComponent.prototype, "seriesMouseLeftButtonDown", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxSeriesViewerComponent.prototype, "seriesMouseLeftButtonUp", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxSeriesViewerComponent.prototype, "seriesMouseMove", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxSeriesViewerComponent.prototype, "seriesMouseEnter", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxSeriesViewerComponent.prototype, "seriesMouseLeave", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxSeriesViewerComponent.prototype, "windowRectChanged", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxSeriesViewerComponent.prototype, "sizeChanged", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxSeriesViewerComponent.prototype, "actualWindowRectChanged", null);
    tslib_1.__decorate([
        Output(),
        tslib_1.__metadata("design:type", EventEmitter),
        tslib_1.__metadata("design:paramtypes", [])
    ], IgxSeriesViewerComponent.prototype, "gridAreaRectChanged", null);
    return IgxSeriesViewerComponent;
}());
export { IgxSeriesViewerComponent };
//# sourceMappingURL=igx-series-viewer-component.js.map