import { IgxSeriesComponent } from "./igx-series-component";
import { DomainChartSeriesPointerEventArgs as DomainChartSeriesPointerEventArgs_internal } from "./DomainChartSeriesPointerEventArgs";
/**
 * Represents event arguments for chart's SeriesAdded and SeriesRemoved events
*
* The `DomainChartSeriesPointerEventArgs` class provide events for chart's SeriesAdded and SeriesRemoved.
*
* `SeriesPointerDown` get fired when the pointer is press down over a Series.
*
* ```html
*  <igx-financial-chart
*       #chart
*       [dataSource]="data"
*       (seriesPointerDown)=chart_seriesPointerDown()
*       >
*     </igx-financial-chart>
* ```
*
* ```ts
* this.chart.seriesPointerDown = this.chart_seriesPointerDown();
* ```
*/
export declare class IgxDomainChartSeriesPointerEventArgs {
    protected _implementation: any;
    /**
     * @hidden
     */
    readonly i: DomainChartSeriesPointerEventArgs_internal;
    private onImplementationCreated;
    constructor();
    protected _provideImplementation(i: any): void;
    /**
     * Gets the series hit by the pointer.
    *
    * Use the `series` property to get the series.
    *
    * ```ts
    *  var series= args.series;
    * ```
    */
    series: IgxSeriesComponent;
    /**
     * Gets the item hit by the pointer.
    *
    * Use the `item` property to get the items.
    *
    * <https://www.infragistics.com/help/wpf/infragisticswpf.controls.charts.xamdatachart~infragistics.controls.charts.domainchartseriespointereventargs~item>
    *
    * ```ts
    * var Chartitem = args.item;
    * ```
    */
    item: any;
}
