import { Type } from '@angular/core';
import { NumericScaleMode } from "./NumericScaleMode";
import { IgxNumericAxisBaseComponent } from "./igx-numeric-axis-base-component";
import { IgxAxisComponent } from "./igx-axis-component";
import { StraightNumericAxisBase } from "./StraightNumericAxisBase";
/**
 * Defines a set of basic methods and properties used to create a StraightNumeric axis.
*/
export declare const IgxStraightNumericAxisBaseComponent_PROVIDERS: {
    provide: typeof IgxAxisComponent;
    useExisting: Type<any>;
}[];
export declare abstract class IgxStraightNumericAxisBaseComponent extends IgxNumericAxisBaseComponent {
    /**
                                 * @hidden
                                 */
    readonly i: StraightNumericAxisBase;
    constructor();
    /**
     * Gets or sets the axis scale mode.
    *
    * `scaleMode` can be used on numeric axes to allow scaling data values using built-in scalers. The available scalers are linear or logarithmic.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis
    *         scaleMode="logarithmic">
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value">
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    * ```ts
    * this.yAxis.scaleMode = NumericScaleMode.Logarithmic;
    * ```
    */
    scaleMode: NumericScaleMode;
}
